/* 
		Exemple d'utilisation de la librairie "IOSelia.lib" sous DOS
		Cet exemple utilise une carte CF01 dont l'adresse de base est configure  0x390.
		La carte est quipe de 2 modules MD03: l'un des modules se trouve  l'emplacement C
		(adrC=0x392) et l'autre se trouve  l'emplacement D (adrD=0x393).
		La carte CF01 est quipe d'un bouchon permettant la recopie de la sortie du 1er module
		sur l'entre du second. Ainsi l'criture d'une valeur  l'adresse 0x392 dclenche une
		interruption (si la valeur est diffrente de la valeur actuelle) car les tats des 
		entres du second module sont modifis. La valeur d'tat peut tre lue  l'adresse 0x393.
*/

#include <stdio.h>
#include <stdlib.h>
#include "iosel.h"

#ifndef DOS
#error	"Cette exemple montre l'utilisation de la librairie "IOSelia.lib" 
		sous Windows DOS. 
#endif

/* Adresse de base d'accs au premier module de la CF01 (emplC=0x392,emplD=0x393) */
#define PORT_BASE				0x378
#define MD03_EMPL_C				0
#define MD03_EMPL_D				0
#define INT_NO            			0     	/* 5 */
#define INT_FUNC				NULL	/*usr_int_function*/
 
int main (int argc,char *argv[])
{										
	ULONG value,read_value;
	ULONG handle;
	BOOL status;

	/* Rservation des ressources suivantes:
			Ports d'entres/sorties 0x392-0x393 et de l'interruption 5
			et dfinition d'une fonction d'interruption utilisateur
	*/

	printf ("Allocation des ressources (ports+interruption)\n");
	status=IOSelia_lock (PORT_BASE,PORT_BASE+3,INT_NO,INT_FUNC,&handle);
  	if (!status) {
		/* Rcupre la dernire erreur du driver (voir les codes erreurs dans "iosel.h") 
			Dans le cas d'une erreur d'allocation de ressource, pensez  utiliser le 
			programme "Systme" du "panneau de configuration" pour visualiser les diffrentes 
      ressources libres en cliquant successivement sur "Gestionnaire de priphriques", puis 
      en double-cliquant sur "ordinateur"
		*/
		DWORD error_code=IOSelia_error();
		if (error_code==IOSELIA_ERROR_BAD_INTERRUPT || error_code==IOSELIA_ERROR_USED_INTERRUPT) {
			printf ("L'interruption %d n'a pu tre rserve\n",INT_NO);
		}
		printf ("Erreur de rservation des ressources\n");
    return 0;
  }
  do {
    printf ("Valeur  crire :");
    scanf("%x",&value);
	  printf ("Ecriture de la valeur %x sur le port %x\n",(int)value,(int)PORT_BASE+MD03_EMPL_C);
	  /* Ecriture d'un octet  l'adresse d'entre/sortie rfrence par le
		    handle, rcupr  la suite de l'appel  Lock, plus un offset.
		    Dans l'exemple ci-dessous, le Outport concerne le port 0x392
	  */
	  IOSelia_outportb(handle,MD03_EMPL_C,value);

	  /* Lecture d'un octet  l'adresse d'entre/sortie rfrence par le
				handle, rcupr  la suite de l'appel  Lock, plus un offset.
				Dans l'exemple ci-dessous, le Inport concerne le port 0x393
	  */
	  IOSelia_inportb(handle,MD03_EMPL_D,&read_value);
	  printf ("Lecture de la valeur %x sur le port %x\n",(int)read_value,(int)PORT_BASE+MD03_EMPL_D);

  } while (value != 0);

	/* Libration des ressources rfrences par le handle rcupr  la suite 
			de l'appel  Lock. Attention, si les ressources ne sont pas libres, 
			elles ne pourront pas tre rserves par un autre programme.
	*/
	printf ("Libration des ressources (ports+interruption)\n");
  if (!IOSelia_unlock(handle)) {
		printf ("Erreur %d lors de la libration des ressources\n",IOSelia_error());
  }
  return 0;
}
